/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_SCRIPT_MANAGER_VIEW_H_
#define _GB2_SCRIPT_MANAGER_VIEW_H_

#include <QtCore/QObject>
#include <QtGui/QDialog>

namespace GB2 {

class ScriptRegistryService;
class ScriptManagerWidgetImpl;
class Task;

class ScriptManagerView : public QObject{
    Q_OBJECT
public:
    ScriptManagerView();
public slots:
    void sl_showWidget();
};

class ScriptManagerDialog : public QDialog {
    Q_OBJECT
public:
    ScriptManagerDialog( ScriptRegistryService * sr, QWidget *p = NULL );
private:
    ScriptManagerWidgetImpl * w;
};

} //namespace

#endif
